{# creata a new ticket #}

{% set category_menu = [('merge-requests', url_tickets_list)] %}
{% extends 'base/base.html' %}
{% block body %}
<div class="box message--info">
    <p>{% trans %}It is not yet possible to create a merge request from inside Libervia, please use <pre>jp merge-request set</pre> for now. Merge requests welcome ;){% endtrans %}</p>
</div>
{% endblock body %}
