{% macro avatar(jid, class) %}
    {%- if identities is defined -%}
        {%- if identities[jid].avatar_basename is defined %}
            <img class="avatar {{class}}" src="{{cache_path}}{{identities[jid].avatar_basename}}">
        {% else %}
            <span class="avatar avatar--generated {{class}}"><span class="avatar__content">{{identities[jid].nick|first|upper}}</span></span>
        {%- endif -%}
    {%- endif -%}
{% endmacro %}
