{% extends 'base/base.html' %}

{% block body %}
{{ icon_defs('level-up', 'doc','folder-open-empty', 'comment-empty') }}
<ul id="files">
    {% if parent_url is defined  %}
        <li class="file">
            <a href="{{ parent_url }}">
                {{ icon('level-up', cls='file__icon') }}
                {% trans %}parent dir{% endtrans %}
            </a>
        </li>
    {% endif %}

    {% for file in files_data %}
        {% if file.type == C.FILE_TYPE_DIRECTORY %}
            <li class="file file_{{file.type}}">
                <a href="{{file.url}}">
                    {{ icon('folder-open-empty', cls='file__icon') }}
                    {{ file.name }}
                </a>
            </li>
        {% else %}
            <li class="file file_{{file.type}}">
                <a href="{{file.url}}">
                    {% if file.thumb_url is defined %}
                        <img src="{{file.thumb_url}}" class="file__thumbnail" alt="{{file.name}}">
                    {% else %}
                        {{ icon('doc', cls='file__icon icon--soft') }}
                    {% endif %}
                    {{ file.name }}
                </a>
            </li>
        {% endif %}
    {% endfor %}
</ul>
{% if not files_data %}
    <p class="message--info">{% trans %}No files are shared in this directory!{% endtrans %}</p>
{% endif%}
{% endblock body %}
