{% import 'components/menu_labels.html' as ml with context %}
{# we need to use "with context" to disable cache, needed for i18n #}

{% macro menu(menus, class='') %}
    <nav class="menu {{class}}">
        <ul>
        {% for name,url in menus %}
            <li><a class="menu_item menu_item--{{name}}" {{ {'href': url}|xmlattr }}>{{ml.label[name]}}</a></li>
        {% endfor %}
        </ul>
        {% if caller is defined %}
            {{ caller()}}
        {% endif %}
    </nav>
{% endmacro %}
