.tickets a.status_closed {
    text-decoration: line-through;
    color: grey;
}
.tickets a.severity_major .xmlui_field__title {
    font-weight: bold;
    color: red;
}

.tickets tbody tr.severity_major .td_title a::before {
    content: '⚠ ';
    color: red;
}

/* single ticket */

.view .xmlui_widget {
    width: auto;
}

.view div.xmlui_cont div.xmlui_cont {
    display: grid;
    grid-template-columns: min-content 1fr;
}

.view #label_wid_publisher,
.view #wid_publisher,
.view #label_wid_title,
.view #label_wid_body,
.view #label_wid_id,
.view #label_wid_comments_uri,
.view #wid_comments_uri {
    display: none
}

.view .xmlui_label {
    padding-right: 2em;
}

.view #wid_id {
    margin: 0;
    font-style: italic;
    grid-column-start: 1;
    grid-column-end: 3;
    text-align: right;
}

.view .xmlui_label {
    font-weight: bold;
    float: left;
    color: #808080cc;
}

.view #wid_title {
    font-weight: bold;
    display: block;
    text-align: center;
    grid-column-start: 1;
    grid-column-end: 3;
}
.view #wid_title::first-letter {
    text-transform: uppercase;
}

.view #wid_labels span, .xmlui_field__labels span {
    font-size: 0.8em;
    background: #eae3e3;
    font-variant: small-caps;
    border: 1px solid black;
    border-radius: 0.5em;
    padding: 0 2px;
    white-space: nowrap;
}

.view #wid_labels span.value_work_in_progress {
    background: yellow;
}

.view #wid_type {
    font-weight: bold;
}

.view #wid_type span.value_bug::after {
    content: ' 🐛';
    color: red;
}

.view #wid_severity span.value_major {
    font-weight: bold;
    color: red;
}

.view #wid_severity span.value_major::after {
    content: '⚠ ';
}

.view #wid_body {
    max-height: 500px;
    overflow: auto;
    resize: vertical;
    background-color: white;
    padding: 5px;
    border-color: #ddd;
    border-style: solid;
    border-width: 1px 0;
    grid-column-start: 1;
    grid-column-end: 3;
    display: block;
}

.comment_post {
    margin-top: 3em;
}


@media (min-width: 800px) {
    ul.xmlui_list {
        padding: 0 2em;
    }
    .xmlui_list li {
        border-radius: 0.3em;
    }
}
