{% if not embedded %}{% extends 'base/base.html' %}{% endif %}
{% import 'input/form.html' as form with context %}
{% import 'input/field.html' as field with context %}

{% block body %}
<p class="instructions--head">{% trans %}Please select the chat room you want to enter{% endtrans %}</p>
<ul class="rooms_list">
{% for room in rooms %}
    <li><a href="{{room.url}}">{{room.name}}</a></li>
{% endfor %}
</ul>
<p class="instructions--alt">{% trans %}Or enter a room address{% endtrans %}</p>
{% call form.form(class="form--single") %}
    {{ field.text("jid", _("Room address (JID)"), required=true)}}
    {{ field.submit(_("Join")) }}
{% endcall %}
{% endblock body %}
