{% import 'input/form.html' as form with context %}
{% import 'input/field.html' as field with context %}

<div class="attendance box">
    <p class="poll_instructions">{% trans %}Please indicate if you plan to attend the event:{% endtrans %}</p>
    {% call form.form() %}
        {{ field.meta("type", "attendance") }}
        {{ field.meta("service", event.invitees_service) }}
        {{ field.meta("node", event.invitees_node) }}
        <div class="attending">
            {{ field.choices("attend", (("yes", _("yes")), ("no", _("no")), ("maybe", _("maybe"))), checked=invitee.attend) }}
        </div>
        <div class="guests">
            {{ field.int("guests", label=_("How many people will come (including you)?"), init=invitee.get("guests", 1)) }}
        </div>
        <div class="submit">
            {{ field.submit() }}
        </div>
    {% endcall %}
</div>
