{% extends 'base/base.html' %}

{% block body %}
<div class='box box--paper'>
    <h1>{% trans %}Welcome {{name}}{% endtrans %}</h1>
    <p class='instructions'>{% trans %}You have been invited to participate to an event{% endtrans %}</p>
    {% if event.image is defined %}
        <p><img id='event_picture' src="{{event.image}}"></p>
    {% endif %}
</div>

{% include 'event/counter.html' %}

{% include 'event/attendance.html' %}

{% if items is defined %}
    {% include 'blog/articles.html' %}
{% endif %}

{% endblock body %}
