{# menu labels, map from menu names to labels #}
{% set label = {
    'login': _('Session') if profile else _('Log in'),
    'blog': _('Blog'),
    'forums': _('Forums'),
    'merge-requests': _('Merge requests'),
    'merge-request_new': _('Create new merge request'),
    'tickets': _('Tickets'),
    'tickets_list': _('List tickets'),
    'ticket_new': _('Create new ticket'),
    'chat': _('Chat'),
    'files': _('Files sharing'),
    'events': _('Events'),
    'event_new': _('Create an event'),
    'photos': _('Photos albums'),
    'app': _('Application'),
} %}
