{# display a single ticket

    @variable item(xmlui_item): ticket to display
    @variable comments(data_object.BlogItems): comments of the ticket
    @variable comments_service(unicode): service for adding comments
    @variable comments_node(unicode): node for adding comments
#}

{% set category_menu = [('tickets', url_tickets_list),
                        ('ticket_new', url_tickets_new),
                        ] %}
{% if not embedded %}{% extends 'base/base.html' %}{% endif %}
{% import 'input/xmlui.html' as xmlui with context %}
{% import 'blog/macros.html' as blog with context %}
{% import 'input/textbox.html' as textbox with context %}

{% block title %}{{item|adv_format('[{value.widget_value.id}] {value.widget_value.title}') }}{% endblock %}

{% block confirm_message %}
    {% trans %}Your comment has been sent{% endtrans %}
{% endblock confirm_message %}

{% block body %}
{{ icon_defs('pencil') }}
<div id="{{ item.widget_value['id'] }}" class="view single ticket box box--medium">
    {% if url_ticket_edit is defined %}
        <p class="box__tools">
            <a href="{{url_ticket_edit}}">
            {{ icon('pencil', cls='icon--text') }}
            edit
            </a>
        </p>
    {% endif %}
    {{ xmlui.generate(item,
        form=false,
        filters={'created': {'filters': ['date_fmt'], 'filters_args':[{'fmt': 'short'}]},
                 'updated': {'filters': ['date_fmt'], 'filters_args':[{'fmt': 'short'}]},
                 'body': {'filters_args':[{'nofollow': True, 'rel': 'noopener noreferrer'}]}},
        )}}
</div>
{% if comments is defined %}
<div id="blog_items">
    {{ blog.show_items(comments|reverse, expanded=true) }}
</div>
{% endif %}
{% if comments_node is defined %}
    <div class="comment_post">
        {{- textbox.comment_or_login(service=comments_service, node=comments_node) -}}
    </div>
{% endif %}
{% endblock body %}
