{% extends 'base/base.html' %}
{% import 'components/block.html' as block %}
{% import 'components/images.html' as images with context %}
{% import 'components/avatar.html' as avatar with context %}
{% import 'input/form.html' as form with context %}
{% import 'input/field.html' as field with context %}

{% block body %}
{{ icon_defs('blog') }}
<p class="instructions--head">
    {% trans %}
    Please select the blog you want to consult
    {% endtrans %}
</p>
<div class="disco_blogs">
    <ul class="grid grid--center">
        {% for entity in disco_entities %}
            <li class='grid__item grid__item--small grid__item--selectable'>
                <a href="{{entities_url[entity]}}" class="items_vert--centered">
                    {{ avatar.avatar(entity, class="avatar--medium") }}
                    <span>{{ identities[entity].nick|default(entity, true) }}</span>
                </a>
            </li>
        {% endfor %}
    </ul>
</div>

{% if disco_entities %}
    <p class="instructions--alt">{% trans %}Or enter the jid of a blog writer{% endtrans %}</p>
{% endif %}
{% call form.form(class="form--single") %}
    {{ field.text("jid", _("blog writer jid"), required=true)}}
    {{ field.submit(_("Consult")) }}
{% endcall %}
{% endblock body %}
