{% extends 'base/base.html' %}
{% import 'input/xmlui.html' as xmlui with context %}

{% block body %}
<div id="tickets">
    {% for ticket in tickets %}
        <div class="ticket_full">
            {{ xmlui.generate(ticket) }}
        </div>
    {% endfor %}
</div>
{% endblock body %}
