.forums {
    margin: 2em auto 0 auto;
    width: 90%;
}

ul.forum {
    list-style: none;
}

ul.forum__panel_sub {
    box-sizing: border-box;
    display: flex;
    flex-flow: row wrap;
    margin: 0 auto;
}

.forum__cat_sub {
    margin: 0.5em 1em;
    width: 25em;
}

.forum__cat_sub>a {
    border: 0.7rem solid #ddd;
    border-radius: 0.5em;
    display: block;
    padding: 1rem;
    margin-bottom: 1rem;
    text-decoration: none;
    color: inherit;
}

a.forum_active:hover {
    background-color: #43d2f6;
}

p.forum_short-desc {
    color: #666;
    margin: 0;
    font-size: 0.8em;
}

.forum__topics {
    margin-top: 3em;
}

.forum__topics>div {
    box-sizing: border-box;
    width: 80%;
    margin: 0.5em auto;
    padding: 0.2em 2em;
    background: #eee;

}

.forum__topics>:hover {
    background-color: #43d2f6;
}

.forum__topics img.avatar {
    vertical-align: middle;
    margin-right: 1em;
}

.forum__topics a {
    display: block;
    text-decoration: none;
    color: inherit;
}

.textbox input {
    width: 100%;
    box-sizing: border-box;
}

@media (min-width: 500px) {
    .textbox input {
        min-width: 26em;
        width: auto;
    }
}
