/* generated from https://google-webfonts-helper.herokuapp.com */

/* *** sat_base_font *** */

/* sat_base_font-regular - latin-ext_latin */
@font-face {
  font-family: 'sat-base-font';
  font-style: normal;
  font-weight: 400;
  src: local('sat-base-font'), local('sat-base-font-Regular'),
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-regular.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-regular.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* sat_base_font-italic - latin-ext_latin */
@font-face {
  font-family: 'sat-base-font';
  font-style: italic;
  font-weight: 400;
  src: local('sat-base-font Italic'), local('sat-base-font-Italic'),
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-italic.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-italic.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* sat_base_font-700 - latin-ext_latin */
@font-face {
  font-family: 'sat-base-font';
  font-style: normal;
  font-weight: 700;
  src: local('sat-base-font Bold'), local('sat-base-font-Bold'),
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-700.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-700.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* sat_base_font-900 - latin-ext_latin */
@font-face {
  font-family: 'sat-base-font';
  font-style: normal;
  font-weight: 900;
  src: local('sat-base-font Black'), local('sat-base-font-Black'),
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-900.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-900.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* sat_base_font-700italic - latin-ext_latin */
@font-face {
  font-family: 'sat-base-font';
  font-style: italic;
  font-weight: 700;
  src: local('sat-base-font Bold Italic'), local('sat-base-font-BoldItalic'),
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-700italic.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-700italic.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* sat_base_font-900italic - latin-ext_latin */
@font-face {
  font-family: 'sat-base-font';
  font-style: italic;
  font-weight: 900;
  src: local('sat-base-font Black Italic'), local('sat-base-font-BlackItalic'),
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-900italic.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('fonts/sat_base_font/sat_base_font-v7-latin-ext_latin-900italic.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}
