{% extends 'base/base.html' %}
{% block body %}
    <article class="box box--large">
        <p>
            {% trans app_name=C.APP_NAME %}
                The following link allows you to access {{app_name}} web application, which is a more feature rich way to use this software (but it is also a bit more heavy and complex to use).
            {% endtrans %}
        </p>
        <p class="warning_text">
            {% trans %}
                Please note that current version of web application use legacy technologies and will be rewritten for next version of Salut à Toi (0.8). It does contain some bugs and it is under minimal maintenance.
            {% endtrans %}
        </p>
        <p id="link_section">
            <a href="/libervia.html">{% trans %}Click here to access the web application{% endtrans %}</a>.
        </p>
        <p>
            {% trans %}
                Next time you can go directly to the above URL.
            {% endtrans %}
        </p>
    </article>
{% endblock body %}
