{{ script.include('chat') }}
{% if not embedded %}{% extends 'base/base.html' %}{% endif %}
{% block title %}{{ target_jid }} - {{ super() }}{% endblock %}
{% block body %}
<div class="chat_widget">
    <div id="messages">
    {% if subject is defined %}
        <div id="subject">
            {{- subject|urlize(nofollow=true,target='_blank') -}}
        </div>
    {% endif %}
    {% for msg in messages %}
        {% include 'chat/message.html' %}
    {% endfor %}
    </div>
    <div class="message_box">
        <textarea id="message_input" name="message" type="text" placeholder="{{_("enter your message")}}"></textarea>
    </div>
</div>
{% endblock body %}

{% block footer %}{% endblock footer %}
