{% extends 'error/base.html' %}

{% block body %}
<h1>{% trans %}Unauthorized{% endtrans %}</h1>
<p>{% trans %}Sorry, you are not authorized to access this page. An authentication is needed.{% endtrans %}</p>
{% endblock body %}
