{% macro form(action='', class='') %}
<form method="post" action="{{action}}" {{ {'class': class}|xmlattr }} {{kwargs|xmlattr}} >
    {% if csrf_token is defined %}
        <input type="hidden" name="csrf_token" value="{{csrf_token}}">
    {% endif %}
    {{ caller() }}
</form>
{% endmacro %}
