#main_area {
    overflow: auto;
}

.rooms_list {
	list-style: none;
    display: grid;
    text-align: center;
    padding: 0;
}

.rooms_list a {
	text-decoration: none;
	color: inherit;
	font-variant: small-caps;
	font-weight: bold;
}

.rooms_list li {
    margin-top: 1em;
}

.rooms_list li:first-child {
    margin-top: 0;
}

.rooms_list li:hover {
    background-color: #efefef;
}

@media (min-width: 600px) {
    .rooms_list {
        grid-template-columns: 1fr 1fr 1fr;
    }

    .rooms_list li {
        margin-top: 0;
    }
}
