.invitation_header {
    text-align: center;
    font-variant: small-caps;
    border: none;
}

.instructions {
    font-style: italic;
    margin: 0;
}

.event__picture {
    max-width: 100%;
    border-radius: 2em;
}

.event__counter {
    font-weight: bold;
    font-size: 1.3em;
    text-align: center;
    width: 15em;
    margin: 1em auto;
    border: 2px solid #aab6c4;
    background-color: #f3e7e7;
    color: #2f3943;
}

.attendance {
    background-color: #9ca0a8;
    padding: 0 0.3em;
    max-width: 580px;
    margin: 0 auto;
    color: #3A3A3A;
}

.attending {
    width: 6em;
    margin: 0 auto;
}

.attending label {
    /* display: inline; */
    margin: 0.8em 0;
}

.guests label {
    display: block;
    margin: 1em 0;
}

.guests input {
    width: 2.5em;
    margin: 0 1em;
}

.poll_instructions {
    font-weight: bold;
    font-size: 0.9em;
    font-size: 1.1em;
    text-align: center;
}

.guests label{
    text-align: center;
    /* font-style: italic */
}

.guests input {
    display: block;
    margin: 0 auto;
}

.submit {
    width: 15em;
    margin: 0 auto;
    padding: 1em 0;
}

.submit input {
    width: 100%;
}

@media (min-width: 500px) {
    .invitation_header {
        width: 94%;
        margin: 0 auto;
        border: solid 1px;
        border-color: #9ca0a8;
    }
}
