.album {
    display: flex;
    flex-wrap: wrap;
}

.album__item {
    width: 400px;
    max-width: 100%;
    margin: 0 0.1em 2em 0.1em;
}

.album__vignette {
    background-color: #444;
    height: 300px;
    position: relative;
}

.album__thumbnail {
    height: 100%;
    display: block;
    margin: 0 auto;
}

.album__comments-bar {
    display: block;
    font-size: 0.8em;
    color: black;
    text-align: right;
    cursor: pointer;
}

.album__comments-bar:hover {
    background-color: #ddd;
    font-weight: bold;
}

.comments__count {
    font-weight: bold;
}
