#files {
    list-style: none;
    display: flex;
    flex-wrap: wrap;
}

.file {
    padding: 0 0 0.5em;
    width: 100px;
    text-overflow: ellipsis;
    overflow: hidden;
    text-align: center;
    overflow-wrap: break-word;
}

.file:hover {
    background: #ddd;
    overflow: visible;
}

.file a {
    text-decoration: none;
    outline: none;
}

.file a:focus img {
    outline: 3px solid #bbb;
}

.file__icon {
    height: 3em;
    display: block;
    margin: 0 auto;
}

.file__thumbnail {
    max-width: 300px;
    height: 125px;
    display: block;
    margin: 0 auto;
}


@media (min-width: 500px) {
    .file {
        padding: 1em;
        width: 170px;
    }
}
