.highlight {
    overflow: auto;
}

.box {
    border-radius: 0;
    box-shadow: none;
}

.ticket {
    max-width: none;
}

.xmlui_cont.xmlui_cont_vertical {
    max-width: 780px;
    margin: 0 auto;
}

#tab_patches {
    overflow: auto;
}

#tab_patches header {
    border-top: 1px solid silver;
}

#tab_patches header label {
    font-weight: bold;
}

.commit_msg {
    font-style: italic;
    white-space: pre-wrap;
}

.diff {
    white-space: pre;
}
