{% if not embedded %}{% extends 'base/base.html' %}{% endif %}
{% import 'input/field.html' as field with context%}
{% import 'input/textbox.html' as textbox with context %}
{% import 'input/navigation.html' as navigation with context %}
{% import 'components/avatar.html' as avatar with context %}

{% block body %}

    {% if not topics %}
        <div class="message--info">
            {% trans %}There is not message yet in this forum.{% endtrans %}
            {% if profile %}
                {% trans %}You can start a topic of interest by filling this form.{% endtrans %}
            {% else %}
                {% trans %}You can login to create a new topic.{% endtrans %}
            {% endif %}
        </div>
    {% endif %}
    {% if profile %}
        <div class="forum__topic_create">
            {% call textbox.textbox(service, node, placeholder=_("Your message"), submit_label=_("Create topic"), type="new_topic") %}
                {{ field.text("title", placeholder=_("Your topic (try to be short and explicit)"), required=True) }}
            {% endcall %}
        </div>
    {% endif %}

    <div class="forum__topics">
        {% for topic in topics %}
            <div>
                <a href="{{topic.http_uri}}">
                    {{ avatar.avatar(topic.author) }}
                    {{topic.title}}
                </a>
            </div>
        {% endfor %}
    </div>

    {{ navigation.prev_next(_("older topics"), _("newer topics")) }}
{% endblock body %}
