{% extends 'base/base.html' %}
{% import 'components/block.html' as block with context %}
{% import 'components/images.html' as images with context %}
{% import 'components/avatar.html' as avatar with context %}
{% import 'input/form.html' as form with context %}
{% import 'input/field.html' as field with context %}

{% block body %}
{{ icon_defs('merge') }}
<p class="instructions--head">
    {% trans %}
    Please select a merge-requests handler
    {% endtrans %}
</p>
{% if mr_handlers is defined %}
    <div class="disco_tickets">
        {{block.disco_icon_grid(mr_handlers, 'merge')}}
    </div>
{% endif %}

{% call form.form(class="form--single") %}
    {{ field.text("jid", _("handler jid"), required=true)}}
    {{ field.submit(_("Access")) }}
{% endcall %}
{% endblock body %}
