{% import 'components/avatar.html' as avatar with context %}

<p id="{{msg.id}}" class="msg_{{msg.type}} {{'own_msg' if msg.from_ == own_jid.full()}}">
    {%- if msg.type != C.MESS_TYPE_INFO %}
        {%- set author = identities[msg.from_].nick | default(msg.from_) -%}
        {{ avatar.avatar(msg.from_, "avatar--float-left") }}
        <span class="msg_header">
            <span class="author">{{author}}</span>
            <span class="date">{{msg.timestamp|date_fmt('auto_day')}}</span>
        </span>
    {% endif -%}
    <span class="msg_body">
        {{- msg.html or (msg.text|urlize(nofollow=true, target="_blank")) -}}
    </span>
</p>
