{# display the list of tickets #}

{% set category_menu = [('ticket_new', url_tickets_new)] %}
{% extends 'base/base.html' %}
{% import 'input/xmlui.html' as xmlui with context %}
{% import 'input/navigation.html' as navigation with context %}

{% block body %}
{{ icon_defs('angle-double-left', 'angle-double-right') }}
<div id="tickets" class="view tickets overview">
    {{ xmlui.generate_list(tickets, (('id', _('Id')),
                                     ('title', _('Title')),
                                     ('labels', _('Labels'))),
                          {'id': '[{value}]'},
                           item_class_fields=['status', 'priority', 'severity'],
                           on_click=on_ticket_click) }}
</div>
{{ navigation.prev_next(_("previous page"), _("next page")) }}
{% endblock body %}
