{% set post_confirm_message=_("You have been logged correctly") %}
{% if not embedded %}{% extends 'base/base.html' %}{% endif %}
{% import 'input/form.html' as form with context %}
{% import 'input/field.html' as field with context %}

{% block title %}{{C.APP_NAME}}{% endblock %}

{% block confirm_message %}
    {% trans %}You have been logged correctly{% endtrans %}
{% endblock confirm_message %}

{% block body %}
<div id='logged'>
    <div class='logged_box box'>
        {% if guest_session %}
            <p>{% trans %}You are logged as a guest{% endtrans %}</p>
        {% else %}
            <p>{% trans name='<span class="logged_profile">'|safe + profile + '</span>'|safe %}You are logged under the account {{name}} {% endtrans %}</p>
        {% endif %}
        <p>{% trans session_started='<span class="logged_time">'|safe + session_started|date_fmt('relative') + '</span>'|safe %}You logged {{session_started}}{% endtrans %}</p>
    </div>
    {% call form.form() %}
        {{ field.meta('type', 'disconnect') }}
        {{ field.submit(_("Disconnect")) }}
    {% endcall %}
</div>
{% endblock body %}
