:root {
  --message_input-height: 2rem;
}

#main_area {
    overflow: hidden;
}

.chat_widget {
	position: absolute;
    height: 100%;
    width: 100%;
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
}

#messages {
    height: 100%;
    min-height: 150px;
    overflow: auto;
    box-sizing: border-box;
    resize: vertical;
    transition: height 0.6s;
}

#subject {
	padding: 1em;
	text-align: center;
	background: #eee;
	font-style: italic;
}

#messages > p {
    margin: 0;
    padding: 0.5em 0 0 0.5em;
}

#messages .msg_body {
    white-space: pre-wrap;
}

#message_input {
    width: 100%;
    height: 100%;
    padding-top: 0.5rem;
    margin: 0;
    box-sizing: border-box;
    resize: none;
}

.message_box {
    flex: 1 1 calc(var(--message_input-height));
    position: relative;
    min-height: 1rem;
    box-sizing: border-box;
}


#messages > p.msg_info {
    white-space: pre-wrap;
    font-family: monospace;
    color: #049282;
}

.msg_header {
	display: block;
	font-size: 0.9em;
}

.author {
    font-weight: bold;
}

.date {
	color: #777;
}
