{% extends 'error/base.html' %}

{% block body %}
<h1>{% trans %}Not Found{% endtrans %}</h1>
<p>{% trans %}Sorry, we can't find the resource you are trying to access.{% endtrans %}</p>
{% endblock body %}
