{# create a new ticket #}

{% set category_menu = [('tickets_list', url_tickets_list)] %}
{% extends 'base/base.html' %}
{% import 'input/form.html' as form with context %}
{% import 'input/field.html' as field with context %}
{% import 'input/xmlui.html' as xmlui with context %}

{% block body %}
<div class='instructions--alt'>
    <p><span class="box">{% trans app_name=C.APP_NAME%}This page allows you to report an issue or ask/suggest a new feature for {{app_name}}{% endtrans %}</span></p>
</div>
<div class="create single ticket box">
{% call form.form() %}
    {{ xmlui.generate(new_ticket_xmlui,
                      attributes = {'title': {'required': 'required',
                                              'placeholder': _("Short description of your issue/request")},
                                    'body': {'required': 'required',
                                             'placeholder': _("Please describe your issue/request with as much details as possible. You can use Markdown syntax.")},
                                    'labels': {'placeholder': _("You can enter one or several labels separated by commas")},
                                    })}}
    {{ field.submit(_("Create ticket")) }}
{% endcall %}
</div>
{% endblock body %}
