{% if days_left is defined %}
    {% if days_left > 0 %}
        <div class="event__counter box">
            {% trans %}
                {{days_left}} day left
            {% pluralize %}
                {{days_left}} days left
            {% endtrans %}
        </div>
    {% else %}
        <div class="event__counter box">{% trans %}the event is finished{% endtrans %}</div>
    {% endif %}

{% endif %}
