{% extends 'login/login.html' %}

{% block title %}{{C.APP_NAME}} register new account{% endblock %}

{% block login_error_message %}
{% if login_error == S_C.ALREADY_EXISTS %}
    {%- trans %}This login already exists, please choose another one.{% endtrans -%}
{% elif login_error == S_C.INVALID_CERTIFICATE %}
    {%- trans %}The certificate of the server is invalid. Please contact your server administrator.{% endtrans -%}
{% elif login_error == S_C.INVALID_INPUT %}
    {%- trans %}The data you entered are not valid.{% endtrans -%}
{% elif login_error == S_C.BAD_REQUEST %}
    {%- trans %}Bad request, please contact your service administrator.{% endtrans -%}
{% else %}
    {%- trans %}An unknown error occurred, please contact your service administrator.{% endtrans -%}
{% endif %}
{% endblock login_error_message %}

{% block login_right_top %}
{% if login_url is defined %}
    <div id="login_link">
        <a href="{{login_url}}">
            {%- trans %}Go to login page{% endtrans -%}
        </a>
    </div>
{% endif %}
{% endblock login_right_top %}

{% block login_form %}
{% call form.form(class='register') %}
    {{ field.meta('type', 'register') }}
    {{ field.text("login", _("Login"),
                  required=true,
                  pattern=S_C.REG_LOGIN_RE,
                  title=_("Login must be lower case, with only plain letters (a-z), numbers (0-9) or underscore(_)"),
                  value=login,
                  )}}
    {{ field.email("email", _("Email"),
                   required=true,
                   value=email,
                   )}}
    {{ field.password("password", _("Password"),
                      required=true,
                      minlength=S_C.PASSWORD_MIN_LENGTH,
                      value=password,
                      )}}
    {{ field.submit(_("Register new account")) }}
{% endcall %}
{% endblock login_form %}

{% block login_right_bottom %}{% endblock %}
