{% extends 'base/base.html' %}

{% block title %}{% trans %}Error {{error_code}}{% endtrans %}{% endblock %}
{% block body %}
{% trans %}An error occured while trying to access the resource.{% endtrans %}
{% endblock body %}
{% block footer %}{% endblock %}
