{% macro get_icon_client(ident) %}
    {% if ident.client %}
        {% if ident.client.pc %}
            {{ icon('desktop', cls='file__icon') }}
        {% elif ident.client.phone %}
            {{ icon('mobile', cls='file__icon') }}
        {% elif ident.client.web %}
            {{ icon('globe', cls='file__icon') }}
        {% elif ident.client.console %}
            {{ icon('terminal', cls='file__icon') }}
        {% else %}
            {{ icon('desktop', cls='file__icon') }}
        {% endif %}
    {% endif %}
{% endmacro %}
