{# create a new event #}

{% extends 'base/base.html' %}
{% import 'input/form.html' as form with context %}
{% import 'input/field.html' as field with context %}

{% block body %}
<div class='instructions--head'>
{% trans %}Create an event{% endtrans %}
</div>
<div class="box--hollow">
{% call form.form(class="form--paper form__panel--vertical") %}
    {{ field.text("name", _("name"), required=true) }}
    {{ field.text("location", _("location"), required=true) }}
    {{ field.textarea("body",
                      _("description of the event"),
                      required=true,
                      class="form__field--medium") }}
    {{ field.date("date", _("date of the event"), required=true) }}
    {{ field.url("main_image", _("event image URL (https)"),
                 title=_("you can enter here the URL to a JPEG or PNG image to use as representation of your event"),
                 placeholder=_("JPEG or PNG image URL"),
                 pattern='http.*(jpg|jpeg|png)') }}
    {{ field.url("bg_image", _("background image URL (https)"),
                 title=_("you can enter here the URL to a JPEG or PNG image to use repeating background"),
                 placeholder=_("JPEG or PNG image URL"),
                 pattern='http.*(jpg|jpeg|png)') }}
    {{ field.submit(_("Create event")) }}
{% endcall %}
</div>
{% endblock body %}
